@@ -37,6 +37,11 @@ def testrunner(options, args):
     options.base_url = CP.get(section, 'base_url')
     options.dsn = None
 
+    if CP.has_option(section, 'support_zope28'):
+        options.support_zope28 = CP.getboolean(section, 'support_zope28')
+    else:
+        options.support_zope28 = False
+
     if CP.has_option(section, 'zope_start'):
         options.zope_start = CP.get(section, 'zope_start')
     else:
@@ -82,7 +87,7 @@ def testrunner(options, args):
 
     if CP.has_option(section, 'tests'):
         raise ValueError("The 'tests' option is deprecated. Use 'packages' instead.")
-            
+
 
     packages = [t.strip() for t in CP.get(section, 'packages').replace('\n','').split(',')]
 
@@ -236,10 +241,18 @@ def run_tests(sandbox_dir, packages, options):
         cmd = ''
         runner_options = ' -vvv '
         runner_options += options.runner_options
-        cmd = 'bin/%s 1>%s 2>&1 test %s -m %s' % (options.zope_start, 
-                                                  tempf,
-                                                  runner_options,
-                                                  package) 
+
+        if options.support_zope28:
+            cmd = 'bin/%s 1>%s 2>&1 test %s --libdir %s' % (options.zope_start, 
+                                                      tempf,
+                                                      runner_options,
+                                                      package) 
+
+        else:
+            cmd = 'bin/%s 1>%s 2>&1 test %s -m %s' % (options.zope_start, 
+                                                      tempf,
+                                                      runner_options,
+                                                      package) 
 
         # execute the Zope testrunner
         if options.verbose:
